Welcome to tox2travis's documentation!
======================================

Contents:

.. toctree::
   :maxdepth: 2

   setup

API:

.. toctree::

    tox2travis

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
